Crate kcr_slo_koordinator_sh

Crate kcr_slo_koordinator_sh 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the slo.koordinator.sh group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

slo.koordinator.sh/v1alpha1

  • NodeMetric
  • NodeSLO

Modules

v1alpha1